@@ -1,8 +1,7 @@
 from typing import Coroutine, Dict, Union, Any, List
 from urllib.parse import unquote
 
-from .codes import STATUS_CODES
-
+import http
 import socket
 import os
 import signal
@@ -10,6 +9,9 @@ import select
 import asyncio
 import re
 import time
+import orjson
+
+STATUS_CODES = {c.value: c.phrase for c in http.HTTPStatus}
 
 class Endpoint:
     def __init__(self, path, method, handler):
@@ -60,7 +62,7 @@ class Request: # class to handle single request from client
         
         self.headers_list: list = []
         
-    async def _handle_headers(self, h): # use _ for most internal functions ig xd
+    async def _handle_headers(self, h: bytes): # use _ for most internal functions ig xd
         headers = h.decode()
         
         self.type, self.path, self.ver = headers.splitlines()[0].split(' ')
@@ -138,12 +140,12 @@ class Request: # class to handle single request from client
                 elif type in ('application/x-www-form-urlencoded', 'x-www-form'):
                     self.parse_form()
         
-    async def send(self, code, b):
+    async def send(self, code: int, b: bytes):
         resp = bytearray()
         rl = [f'HTTP/1.1 {code} {STATUS_CODES.get(code)}']
         
         if b:
-            rl.append(f'Content-Type: {len(b)}')
+            rl.append(f'Content-Length: {len(b)}')
             
         for key, val in self.resp_headers.items():
             rl.append(f'{key}: {val}')
@@ -159,7 +161,7 @@ class Request: # class to handle single request from client
             pass
         
 class Router:
-    def __init__(self, domain):
+    def __init__(self, domain: Union[str, set]):
         self.domain: Union[str, set] = domain # i may accept regex in the future
         self.endpoints = set() # endpoints current router handles (server can have multiple routers, useful for multi-file impl)
 
@@ -175,7 +177,7 @@ class Router:
         elif isinstance(self.domain, str):
             self.cond = lambda d: d == self.domain
         
-    def route(self, path, method: List[str] = ['GET']): # route decorator
+    def route(self, path: str, method: List[str] = ['GET']): # route decorator
         def wrapper(_coro: Coroutine):
             if all(c in path for c in ('<', '>')): # thank you lenforiee cus i absolutely hate regex
                 np = re.compile(rf"{path.replace('<', '(?P<').replace('>', '>.+)')}")
@@ -213,7 +215,7 @@ class Xevel: # osu shall never leave my roots
     def add_router(self, router: Router):
         self.routers.add(router)
         
-    def add_task(self, _coro: Coroutine):
+    def add_task(self, _coro):
         self.coros.add(_coro)
 
     def before_serving(self):
@@ -228,7 +230,7 @@ class Xevel: # osu shall never leave my roots
             return _coro
         return wrapper
     
-    async def handle_req(self, c):
+    async def handle_req(self, c: socket.socket):
         req = Request(c, self.loop) # request object kinda cooooooool i think
         await req.parse_req()
         
@@ -277,6 +279,9 @@ class Xevel: # osu shall never leave my roots
         if isinstance(resp, tuple):
             code, resp = resp # fix response into var
             
+        if isinstance(resp, dict):
+            resp = orjson.dumps(resp) # jsonify response
+            
         if isinstance(resp, str):
             resp = resp.encode() # encode response into bytes for client ready xd
             
@@ -296,7 +301,7 @@ class Xevel: # osu shall never leave my roots
         for _coro in router.after_reqs:
             await _coro(req) # handle any coroutines before ending request | send request so they can take some attributes from it
             
-    def get_router(self, host):
+    def get_router(self, host: str):
         for r in self.routers:
             if r.cond(host):
                 return r
@@ -312,9 +317,10 @@ class Xevel: # osu shall never leave my roots
             else:
                 raise TypeError('Please use the correct address format!') # raising exceptions kinda cooooooool
             
-            if t is socket.AF_UNIX: # dddddddddddddd
-                if os.path.exists(self.address):
-                    os.remove(self.address)
+            if os.name != 'nt':
+                if t is socket.AF_UNIX: # dddddddddddddd
+                    if os.path.exists(self.address):
+                        os.remove(self.address)
                     
             for _coro in self.before_serves:
                 await _coro()
@@ -322,7 +328,7 @@ class Xevel: # osu shall never leave my roots
             for _coro in self.coros:
                 if isinstance(_coro, tuple):
                     coro, args = _coro
-                    t = self.loop.create_task(coro(*args))
+                    t = self.loop.create_task(coro(args))
                 else:
                     t = self.loop.create_task(_coro())
                 
@@ -335,20 +341,22 @@ class Xevel: # osu shall never leave my roots
             
             self.socket.bind(self.address)
             
-            if t is socket.AF_UNIX:
-                os.chmod(self.address, 0o777) # full permissions to socket file to prevent any potential perm issues xd
+            if os.name != 'nt':
+                if t is socket.AF_UNIX:
+                    os.chmod(self.address, 0o777) # full permissions to socket file to prevent any potential perm issues xd
                 
             self.socket.listen()
             
             # i am trying to make this as original as possible while it also being my first attempt, bare with me!!
             r, w = os.pipe()
-            os.set_blocking(w, False)
+            if os.name != 'nt':
+                os.set_blocking(w, False)
             signal.set_wakeup_fd(w)
             
             close = False
             
             while True: # loop to accept connections? i might redo this system when i learn more about the internals of what im doing here...
-                await asyncio.sleep(0.01)
+                await asyncio.sleep(0.001)
                 rl, _, _ = select.select([self.socket, r], [], [], 0) # what :smiley: | ok i kinda understand this now :p
                 
                 for rd in rl:
@@ -399,7 +407,12 @@ class Xevel: # osu shall never leave my roots
             self.loop.stop()
         
         # we wanna ignore these signals?
-        for sig in (signal.SIGINT, signal.SIGTERM, signal.SIGHUP):
+        if os.name == 'nt': # windows
+            sig_ig = (signal.SIGINT, signal.SIGTERM)
+        else:
+            sig_ig = (signal.SIGINT, signal.SIGTERM, signal.SIGHUP)
+
+        for sig in sig_ig:
             signal.signal(sig, _ignore_signal)
         
         f = asyncio.ensure_future(run_server(), loop=self.loop)
@@ -409,4 +422,4 @@ class Xevel: # osu shall never leave my roots
             self.loop.run_forever()
         finally:
             f.remove_done_callback(_run_cb)
-            self.loop.close()
\ No newline at end of file
+            self.loop.close()
